@@ -121,37 +121,22 @@ class ITagger(Interface):
         """
         returns a list of user uris
         """
-    
-    def isGroup(id_, context=None):
-        """ determines if an id is a group or not """
-    
-    def groupNodes(nodes, group=None, spec=None, context=None):
-        """add 1-N tags to a group"""
-    
-    def ungroupNodes(nodes, group=None, context=None):
-        """remove 1-N tags from a group or all groups"""
-        
-    def createRule(spec, context=None):
-        """ create a rule to be interpretted by external system"""
 
-    def setRule(node, rule, context=None):
-        """set rule on node for later interpretation"""
-    
-    def removeRule(node, rule, context=None):
-        """ remove rule from rdf node"""
-
-    def ruleApplies(node, rule, context=None):
-        """
-        checks if rule applies to node
-        
-        @return boolean
-        """
-    
     def annotations(tag=None, user=None, item=None, context=None):
         """ annotations by intersection """
     
-    def annotations_by(subject, context=None):
-        """@return all annotations for a subject """
+    def annotations_by(self, pred, subject, spec=None):
+        """
+        simple scope query to return all nodes represent annotations
+        for a particular 'subject' of relation 'pred'
+
+        @param subject: node id for item of interest
+        
+        @param pred:    predicate defining relationship of subject to an
+                        annotation.
+
+        @return         list of node ids for annotations
+        """
     
     def intersect(s1, s2, context=None):
         """
@@ -189,3 +174,21 @@ class ITagger(Interface):
         @param spec: rdf predicate and object for new node created
         @type spec: tuple
         """
+
+    def items_for_tag(self, subject, spec=None):
+        """ returns id for items tags by string:subject """
+
+    def items_for_user(self, subject, spec=None):
+        """ for item for user id """
+
+    def users_for_tag(self, subject, spec=None):
+        """ for item for user id """
+
+    def users_for_item(self, subject, spec=None):
+        """ for item for user id """
+
+    def tags_for_item(self, subject, spec=None):
+        """ for item for user id """
+
+    def tags_for_user(self, subject, spec=None):
+        """ for item for user id """
